@@ -204,7 +204,7 @@ class MinDalle:
                 attention_state,
                 image_tokens
             )
-            if mid_count is not None and row_index + 1 < row_count:
+            if mid_count is not None:
                 if ((row_index + 1) * mid_count) % row_count == 0:
                     tokens = image_tokens[:, 1:]
                     image = self.image_from_tokens(grid_size, tokens)
